@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -205,6 +205,12 @@ sub _detect_linux_distribution_lsb_release {
 }
 
 sub _detect_linux_distribution_fallback {
+    if (open my $fh, '<', '/etc/redhat-release') {
+	my $contents = <$fh>;
+	if ($contents =~ m{^(CentOS|RedHat) Linux release (\d+)\S* \((.*?)\)}) {
+	    return {linuxdistro => $1, linuxdistroversion => $2, linuxdistrocodename => $3};
+	}
+    }
     if (open my $fh, '<', '/etc/issue') {
 	chomp(my $line = <$fh>);
 	if      ($line =~ m{^Linux Mint (\d+) (\S+)}) {
@@ -216,6 +222,7 @@ sub _detect_linux_distribution_fallback {
 		 6 => 'squeeze',
 		 7 => 'wheezy',
 		 8 => 'jessie',
+		 9 => 'stretch',
 		}->{$info{linuxdistroversion}};
 	    return \%info;
 	} else {
@@ -393,6 +400,33 @@ sub _find_missing_deb_packages {
     @missing_packages;
 }
 
+sub _find_missing_rpm_packages {
+    my($self, @packages) = @_;
+    return () if !@packages;
+
+    my @missing_packages;
+
+    {
+	my %packages = map{($_,1)} @packages;
+
+	local $ENV{LC_ALL} = 'C';
+	my @cmd = ('rpm', '-q', @packages);
+	open my $fh, '-|', @cmd
+	    or die "Error running '@cmd': $!";
+	while(<$fh>) {
+	    if (m{^package (\S+) is not installed}) {
+		my $package = $1;
+		if (!exists $packages{$package}) {
+		    die "Unexpected: package $package listed as non-installed, but not queries in '@cmd'?!";
+		}
+		push @missing_packages, $package;
+	    }
+	}
+    }
+
+    @missing_packages;
+}
+
 sub _find_missing_freebsd_pkg_packages {
     my($self, @packages) = @_;
     return () if !@packages;
@@ -453,6 +487,8 @@ sub _filter_uninstalled_packages {
     my $find_missing_packages;
     if      ($self->_is_apt_installer) {
 	$find_missing_packages = '_find_missing_deb_packages';
+    } elsif ($self->{installer} eq 'yum') {
+	$find_missing_packages = '_find_missing_rpm_packages';
     } elsif ($self->{os} eq 'freebsd') {
 	$find_missing_packages = '_find_missing_freebsd_pkg_packages';
     } elsif ($self->{os} eq 'MSWin32') {
@@ -509,6 +545,8 @@ sub _install_packages_commands {
     if ($self->{batch}) {
 	if ($self->_is_apt_installer) {
 	    push @install_cmd, '-y';
+	} elsif ($self->{installer} eq 'yum') {
+	    push @install_cmd, '-y';
 	} elsif ($self->{installer} eq 'pkg') { # FreeBSD's pkg
 	    # see below
 	} elsif ($self->{installer} eq 'homebrew') {
@@ -519,6 +557,8 @@ sub _install_packages_commands {
     } else {
 	if ($self->_is_apt_installer) {
 	    @pre_cmd = ('sh', '-c', 'echo -n "Install package(s) '."@packages".'? (y/N) "; read yn; [ "$yn" = "y" ]');
+	} elsif ($self->{installer} eq 'yum') {
+	    # interactive by default
 	} elsif ($self->{installer} eq 'pkg') { # FreeBSD's pkg
 	    # see below
 	} elsif ($self->{installer} =~ m{^(chocolatey)$}) {
