@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 # shortcuts
 #  os and distros
@@ -11,6 +11,7 @@ use constant os_freebsd  => (os => 'freebsd');
 use constant os_windows  => (os => 'MSWin32');
 use constant os_darwin   => (os => 'darwin'); # really means installer=homebrew
 use constant like_debian => (linuxdistro => '~debian');
+use constant like_fedora => (linuxdistro => '~fedora');
 #  package shortcuts
 use constant freebsd_jpeg => 'jpeg | jpeg-turbo';
 
@@ -137,7 +138,10 @@ sub mapping {
      [cpanmod => 'App::Stacktrace',
       # does not work with freebsd anyway
       [like_debian,
-       [package => 'gdb']]],
+       [package => 'gdb']],
+      [like_fedora,
+       [package => 'gdb']],
+     ],
 
      [cpanmod => 'Archive::Rar',
       [os_freebsd,
@@ -295,6 +299,8 @@ sub mapping {
        [package => 'cairo']],
       [like_debian,
        [package => 'libcairo2-dev']],
+      [like_fedora,
+       [package => 'cairo-devel']],
       [os_darwin,
        [package => 'cairo']]],
 
@@ -604,7 +610,7 @@ sub mapping {
      [cpanmod => 'File::ExtAttr',
       [like_debian,
        [package => 'libattr1-dev']],
-      [linuxdistro => '~fedora',
+      [like_fedora,
        [package => 'libattr-devel']],
      ],
 
@@ -642,7 +648,7 @@ sub mapping {
       [os_freebsd,
        [package => 'ta-lib']]], # alternative would be Alien::TALib
 
-     [cpanmod => 'FTDI::D2XX',
+     [cpanmod => ['FTDI::D2XX', 'Device::FTDI'],
       # neither libftdi nor libftdi1 seem to work on FreeBSD
       [like_debian,
        [package => 'libftdi-dev']]],
@@ -680,6 +686,8 @@ sub mapping {
        [linuxdistrocodename => ['precise', 'wheezy'],
 	[package => 'libgd2-noxpm-dev | libgd2-xpm-dev']],
        [package => 'libgd-dev']],
+      [like_fedora,
+       [package => 'gd-devel']],
       [os_darwin,
        [package => 'gd']]],
 
@@ -737,6 +745,11 @@ sub mapping {
 	[package => []]], # N/A
        [package => 'libgit2-dev']]],
 
+     [cpanmod => 'Glib',
+      [like_fedora,
+       [package => 'gobject-introspection-devel']],
+     ],
+
      [cpanmod => 'Glib::Object::Introspection',
       [os_freebsd,
        [package => 'gobject-introspection']],
@@ -977,6 +990,8 @@ sub mapping {
        [linuxdistrocodename => ['wheezy', 'precise'],
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
        [package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev libtiff5-dev)]]],
+      [like_fedora,
+       [package => [qw(freetype-devel giflib-devel libpng-devel libjpeg-turbo-devel libtiff-devel)]]],
       [os_darwin,
        [package => [qw(freetype giflib libpng jpeg libtiff)]]],
      ],
@@ -1097,8 +1112,11 @@ sub mapping {
        [package => 'libacl1-dev']]],
 
      [cpanmod => 'Linux::Inotify2',
-      [os_freebsd,
-       [package => 'libinotify']],
+      ## This inotify package is not able to run
+      ## Linux::Inotify2, and if installed it
+      ## casues problems with Alien-wxWidgets
+      #[os_freebsd,
+      # [package => 'libinotify']],
       [like_debian,
        [package => 'libc6-dev']]],
 
@@ -1222,7 +1240,8 @@ sub mapping {
       [os_freebsd,
        [package => ['alsa-lib', 'alsa-utils']]],
       [like_debian,
-       [package => 'alsa-utils']]],
+       [package => ['libasound2-dev', 'alsa-utils']]],
+     ],
 
      [cpanmod => 'MP3::ID3Lib',
       [os_freebsd,
@@ -1421,6 +1440,8 @@ sub mapping {
        [package => 'pango']],
       [like_debian,
        [package => 'libpango1.0-dev']],
+      [like_fedora,
+       [package => 'pango-devel']],
       [os_darwin,
        [package => 'pango']],
      ],
@@ -1620,6 +1641,8 @@ sub mapping {
      [cpanmod => 'Term::ReadLine::Gnu',
       [like_debian,
        [package => 'libreadline6-dev']],
+      [like_fedora,
+       [package => 'readline-devel']],
       # XXX what about freebsd?
       # XXX no homebrew package for darwin (checked 2016-05-22)
      ],
@@ -1692,7 +1715,7 @@ sub mapping {
        [package => qw(freetype2 libXft libX11 png), freebsd_jpeg]],
       [like_debian,
        [package => [qw(libx11-dev libfreetype6-dev libxft-dev libpng-dev libz-dev libjpeg-dev)]]],
-      [linuxdistro => '~fedora',
+      [like_fedora,
        [package => [qw(libX11-devel libXft-devel libpng-devel zlib-devel libjpeg-devel)]]],
      ],
 
@@ -1732,6 +1755,8 @@ sub mapping {
      [cpanmod => 'URPM',
       [like_debian,
        [package => 'librpm-dev']], # but does not work anyway with the librpm version as found on squeeze
+      [like_fedora,
+       [package => 'rpm-devel']],
       # XXX what about freebsd?
      ],
 
@@ -1762,7 +1787,10 @@ sub mapping {
      [cpanmod => 'WWW::Curl',
       # XXX freebsd?
       [like_debian,
-       [package => 'libcurl4-openssl-dev | libcurl4-gnutls-dev | libcurl4-nss-dev']]],
+       [package => 'libcurl4-openssl-dev | libcurl4-gnutls-dev | libcurl4-nss-dev']],
+      [like_fedora,
+       [package => 'libcurl-devel']],
+     ],
 
      [cpanmod => 'WWW::Mechanize::PhantomJS',
       [os_freebsd,
@@ -1782,21 +1810,27 @@ sub mapping {
       [os_freebsd,
        [package => 'libxml2']],
       [like_debian,
-       [package => 'libxml2-dev']]],
+       [package => 'libxml2-dev']],
+      [like_fedora,
+       [package => 'libxml2-devel']],
+     ],
 
      [cpanmod => 'XML::LibXSLT',
       [os_freebsd,
        [package => 'libxslt']],
       [like_debian,
        [package => ['libxslt1-dev', 'libgdbm-dev']]],
-      [linuxdistro => '~fedora',
+      [like_fedora,
        [package => 'libxslt-devel']]],
 
      [cpanmod => 'XML::Parser',
       [os_freebsd,
        [package => 'expat']],
       [like_debian,
-       [package => 'libexpat1-dev']]],
+       [package => 'libexpat1-dev']],
+      [like_fedora,
+       [package => 'expat-devel']],
+     ],
 
      [cpanmod => 'XML::Sablotron',
       # compiles only with perl < 5.14, see https://rt.cpan.org/Ticket/Display.html?id=66849
